@@ -4,7 +4,7 @@ from typing import OrderedDict, Union
 
 from expressmoney.api import *
 
-SERVICE_NAME = 'loans'
+SERVICE = 'loans'
 
 
 class LoanCreateContract(Contract):
@@ -57,13 +57,27 @@ class PayUpdateContract(Contract):
     bank_card_id = serializers.IntegerField()
 
 
-loans_loans_loan = ID(SERVICE_NAME, 'loans', 'loan')
-loans_loans_loan_pagination_none = ID(SERVICE_NAME, 'loans', 'loan', 'pagination_none')
-loans_loans_pay = ID(SERVICE_NAME, 'loans', 'pay')
+class LoanID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'loan'
+
+
+class LoanPaginationNoneID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'loan'
+    _action = 'pagination_none'
+
+
+class PayID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'pay'
 
 
 class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = loans_loans_loan
+    _point_id = LoanID()
     _read_contract = LoanReadContract
     _create_contract = LoanCreateContract
 
@@ -76,22 +90,10 @@ class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
 
 
 class LoanPaginationNonePoint(ListPointMixin, ContractPoint):
-    _point_id = loans_loans_loan_pagination_none
+    _point_id = LoanPaginationNoneID()
     _read_contract = LoanPaginationNoneReadContract
 
 
 class PayPoint(UpdatePointMixin, ContractObjectPoint):
-    _point_id = loans_loans_pay
+    _point_id = PayID()
     _update_contract = PayUpdateContract
-
-
-"""
-from django.contrib.auth import get_user_model
-User = get_user_model()
-user = User.objects.get(id=1)
-
-from loans.models import Loan
-loan = Loan.objects.get(id=47)
-print(loan.body_balance)
-
-"""
