@@ -1,4 +1,4 @@
-__all__ = ('BankCardPoint',)
+__all__ = ('BankCardPoint', 'BankCard3dsPoint')
 
 from expressmoney.api import *
 
@@ -83,13 +83,29 @@ class BankCardReadContract(BankCardCreateContract):
     gateway = serializers.ChoiceField(choices=GATEWAY_CHOICES)
 
 
+class BankCard3dsContract(Contract):
+    md = serializers.CharField(max_length=512)
+    pa_res = serializers.CharField(max_length=512)
+
+
 class BankCardID(ID):
     _service = SERVICE
     _app = 'bank_cards'
     _view_set = 'bank_card'
 
 
+class BankCard3dsID(ID):
+    _service = SERVICE
+    _app = 'bank_cards'
+    _view_set = 'bank_card_3ds'
+
+
 class BankCardPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = BankCardID()
     _create_contract = BankCardCreateContract
     _read_contract = BankCardReadContract
+
+
+class BankCard3dsPoint(CreatePointMixin, ContractPoint):
+    _point_id = BankCard3dsID()
+    _create_contract = BankCard3dsContract
